/*
 * @(#)APFactory.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge;

/**
 * This class holds the factory methods for the AP class. Users can
 * use this class to create instances of AP objects with their desired
 * parameters.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 *
 * @see AP
 */

public interface APFactory {
    /**
     * The static variable that is used to call the create() methods to
     * create instances of the AP.
     */
    public static APFactory factory = null;

    /**
     * The factory method to create a default instance of AP without ay
     * parameters.
     * @return a default instance of AP
     */
    public AP create();

    /**
     * The factory method to create an instance of AP with the given
     * lexical entry.
     * @param lex the lexical entry of the FD
     * @return an instance of AP which is instantiated with a given
     * lexical entry.
     */
    public AP create(String lex) throws InvalidConstructorException;

    /**
     * The factory method to create an instance of AP with the given
     * head entry represented as a FD.
     * @head the head of the AP
     * @return an instance of AP which is instantiated with a given
     * head entry.
     */
    public AP create(FD head) throws InvalidConstructorException;
}
