/*
 * @(#)Circum.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge;

/**
 * The circumstance category. This is often used together with the
 * Clause, Proc and Partic classes because the parimary usage of a
 * circumstance is to describe the settings of the process of a
 * clause. This class has methods to set the lexical entry which tells
 * the circumstance and also has methods to set the characteristics of
 * the circumstance.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 *
 * @see CircumFactory
 * @see Clause
 * @see Proc
 * @see Partic
 * @see PreMod
 */

public interface Circum extends FD {
    /**
     * A method to set the lexical entry of the circumstance.
     * @param lex
     */
    public void setLex(String lex);

    /**
     * A method to set the behalf of the circumstance.
     * @param behalf
     */
    public void setBehalf(FD behalf);

    /**
     * A method to set the time of the circumstance.
     * @param time
     */
    public void setTime(FD time);

    /**
     * A method to set the in-loc of the circumstance.
     * @param in_loc
     */
    public void setInLoc(FD in_loc);

    /**
     * A method to set the effect of the circumstance.
     * @param effect
     */
    public void setEffect(FD effect);

    /**
     * A method to set the manner of the circumstance.
     * @param manner
     */
    public void setManner(FD manner);

    /**
     * A method to set the purpose of the circumstance.
     * @param purpose
     */
    public void setPurpose(FD purpose);

    /**
     * A method to set the reason of the circumstance.
     * @param reason
     */
    public void setReason(FD reason);
}
