/*
 * @(#)CircumFactory.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge;

/**
 * This class holds the factory methods for the Circum class. Users
 * can use this class to create instances of Circum objects with their
 * desired parameters.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 *
 * @see Circum
 */

public interface CircumFactory {
    public static CircumFactory factory = null;

    /**
     * The default factory method which creates an default instance of
     * Circum object without any parameters.
     * @return a default instance of Circum.
     */
    public Circum create();

    /**
     * The factory method which creates an instance of Circum object
     * with the given entries that tell and specify the circumstance. If
     * invalid parameters are input, an exception will be thrown.
     * @param propertyName the name of the circumstance property
     * @param propertyBody the body of the circumstance property
     * @param lex the possible lexical entry of the circumstance
     * @return an instance of Circum instantiated with the property
     * name and the specified properties.
     * @exception InvalidConstructorException
     */
    public Circum create(String propertyName, FD propertyBody, String lex) 
	throws InvalidConstructorException;

    /**
     * The factory method which creates an instance of Circums object
     * with the given entries that tell and specify the
     * circumstance. This constructor accounts for all possible
     * cirsumtances that users can specify. Among all the possible
     * input circumstance characteristics, users should only enter one
     * characteristic and set the rest of them be null. Otherwise, if
     * more than one characteristics is inputted, an exception should
     * be thrown. If invalid parameters are input, an exception will
     * be thrown.
     * @param behalf the behalf characteristics of the circumstance
     * @param effect the effect characteristics of the circumstance
     * @param inLoc the in-location characteristics of the circumstance
     * @param manner the manner characteristics of the circumstance
     * @param purpose the purpose characteristics of the circumstance
     * @param reason the reason characteristics of the circumstance
     * @param time the time characteristics of the circumstance
     * @param lex the possible lexical entry of the circumstance
     * @return an instance of Circum instantiated with the property
     * name and the specified properties.
     * @exception InvalidConstructorException
     */
    public Circum create(FD behalf, FD effect, FD inLoc, FD manner, 
			 FD purpose, FD reason, FD time, String lex) 
	throws InvalidConstructorException;
}
