/*
 * @(#)Common.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge;

/**
 * The Common category for a FD. Methods to set the lex and the head
 * of the common category are provided. There are a lot of variations
 * you can make to the noun such as setting it to be definite,
 * plural... Since there are too many options and they are not common,
 * methods are not provided to set those properties. And setLex() will
 * be the only required/automate method provided here.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 *
 * @see CommonFactory
 */

public interface Common extends FD {
    /**
     * A method to set the head of the common category
     * @param lex the lexical entry of the common phrase
     */
    public void setLex(String lex);

    /**
     * A method to set whether the common cat should be definite
     * @param true to be definite, false to be non-definite
     */
    public void setDefinite(boolean definite);
}
