/*
 * @(#)CommonFactory.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge;

/**
 * This class holds the factory methods for the Common class. Users can
 * use this class to create instances of Common objects with their
 * desired parameters.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 *
 * @see Common
 */

public interface CommonFactory {
    /**
     * The static instance which helps users to access to the methods in
     * this class.
     */
    public static CommonFactory factory = null;

    /**
     * A factory method which creates an instance of Common without any
     * given parameters.
     */
    public Common create();

    /**
     * A factory method which creates an instance of Common with the
     * given lexical entry. If the lexical entry is invalid, an
     * InvalidConstructorException should be thrown.
     * @param lex lexical entry
     */
    public Common create(String lex)
	throws InvalidConstructorException;

    /**
     * A factory method which creates an instance of Common with the
     * given lexical entry and a boolean to specify whether the lex
     * should be definite.  If the lexical entry is invalid, an
     * InvalidConstructorException should be thrown.
     * @param lex lexical entry
     * @param definite set whether the lex should be definite. Input
     * true to be definite.
     */
    public Common create(String lex, boolean definite) 
	throws InvalidConstructorException;
}
