/*
 * @(#)FDProperties.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge;

/**
 * This interface serves to provide all the common property value
 * constants that FDs will use in order to set their properties. For
 * example, the Proc class (the process of a clause) will use the
 * constants in this class to set its tense, restrictiveness... This
 * interface primarily just stores a pool of common and frequently
 * constants that other classes may be able to take advantage of.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 */

public interface FDProperties {
    /**
     * The variable that allows users to set the tense to past. By
     * default, a sentence is in present tense.
     */
     public static final String PAST_TENSE = "past";

     /**
      * The variable that allows users to set the tense to present.
      */
      public static final String PRESENT_TENSE = "present";

    /**
      * The variable that allows users to set the polarity to
      * positive.
      */
      public static final String POSITIVE_POLARITY =  "positive";

    /**
      * The variable that allows users to set the polarity to
      * netgative.
      */
      public static final String NEGATIVE_POLARITY =  "negative";

    /**
      * The variable that allows users to set the mood to wh.
      */
      public static final String WH_MOOD =  "wh";

    /**
     * The variable that allows users to set the mood to present
     * participle.
     */
     public static final String PRESENT_PARTICIPLE_MOOD =  "present-participle";

    /**
     * The variable that allows users to set the mood to past
     * participle.
     */
     public static final String PAST_PARTICIPLE_MOOD =  "past-participle";

    /**
     * The variable that allows users to set the mood to
     * to-infinitive.
     */
     public static final String TO_INFINITIVE_MOOD =  "to-infinitive";

    /**
     * The variable that allows users to set the mood to imperative.
     */
     public static final String IMPERATIVE_MOOD =  "imperative";

     /**
     * The variable that allows users to set the mood to yes-no.
     */
     public static final String YES_NO_MOOD =  "yes-no";

     /**
     * The variable that allows users to set the mood to
     * bound-nominal-subjunctive.
     */
     public static final String BOUND_NOMINAL_SUBJUNCTIVE_MOOD =  "bound-nominal-subjunctive";

     /**
     * The variable that allows users to set the mood to relative.
     */
     public static final String RELATIVE_MOOD =  "relative";

    /**
     * The variable that allows users to set the mood to bound.
     */
     public static final String BOUND_MOOD =  "bound";

    /**
     * The variable that allows users to set the mood to declarative.
     */
     public static final String DECLARATIVE_MOOD =  "declarative";

    /**
     * The variable that allows users to set the restrictiveness to
     * restrictive.
     */
     public static final String RESTRICTIVE =  "yes";

    /**
     * The variable that allows users to set the restrictivenes to
     * non- restrictive.
     */
     public static final String NON_RESTRICTIVE =  "no";

     /**
      * The variable that allows users to set the complexity to be an
      * apposition.
      */
     public static final String APPOSITION =  "apposition";

     /**
      * The variable that allows users to set the complexity to be a
      * conjunction.
      */
     public static final String CONJUNCTION =  "conjunction";

     /**
      * The variable that allows users to set the lex to plural.
      */
     public static final String PLURAL =  "plural";

     /**
      * The variable that allows users to set the lex to single.
      */
     public static final String SINGULAR =  "singlular";

     /**
      * The variable that allows users to set the lex to dual.
      */
     public static final String DUAL =  "dual";

     /**
      * The variable that allows users to set the lex to definite.
      */
     public static final String DEFINITE =  "yes";

     /**
      * The variable that allows users to set the lex to non-definite.
      */
     public static final String NON_DEFINITE =  "no";

     /**
      * The variable that allows users to declare the lex to be
      * countable.
      */
     public static final String COUNTABLE =  "yes";

     /**
      * The variable that allows users to declare the lex to be
      * non-countable.
      */
     public static final String NON_COUNTABLE =  "no";

     /**
      * The variable that allows users to set the interrogativeness to
      * be interrogative.
      */
     public static final String INTERROGATIVE =  "yes";

     /**
      * The variable that allows users to set the interrogativeness to
      * be non-interrogative.
      */
     public static final String NON_INTERROGATIVE =  "no";

     /**
      * The variable that allows users to set the possessiveness to be
      * possessive.
      */
     public static final String POSSESSIVE =  "yes";

     /**
      * The variable that allows users to set the possessiveness to be
      * non-possessive.
      */
     public static final String NON_POSSESSIVE =  "no";

     /**
      * The variable that allows users to set the distance to be far.
      */
     public static final String FAR =  "far";

     /**
      * The variable that allows uers to set the distance to be near.
      */
     public static final String NEAR =  "near";

     /**
      * The variable that allows users to set to selective.
      */
     public static final String SELECTIVE =  "yes";

     /**
      * The variable that allows users to set to non-selective.
      */
     public static final String NON_SELECTIVE = "no";

}
