/*
 * @(#)InvalidPathException.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge;

/**
 * This exception is thrown when users feed in an invalid path name
 * into any method that needs to process path names.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 */

public class InvalidPathException extends Exception {
  /**
    * Constructs a new instance of InvalidPathException.  All fields
    * are set to null.
    */
  public InvalidPathException() {
    super();
    pathNameArray = null;
  }

  /**
    * Constructs a new instance of InvalidPathException with a given
    * pathName.
    * @param pathName the pathName to be thrown if it is invalid, specified by a
    *                 string array of path names
    */
  public InvalidPathException(String[] pathName) {
    super();
    this.pathNameArray = pathName;
  }

  /**
   * A method to state the error message when this exception is thrown.
   * @return an error message for this exception
   */
  public String toString() {
    if (pathNameArray != null) {
      String pathNameString = "";
      for ( int i = 0; i < pathNameArray.length; i++ )
        pathNameString += pathNameArray[i] + " ";
      return "InvalidPathException is caught. Input path:" + 
	  pathNameString + " is invalid.";
    } else
	return "InvalidPathException is caught. The input path is empty.";
  }

  private static String[] pathNameArray;
}
