/*
 * @(#)NPFactory.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge;

/**
 * This class holds the factory methods for the NP class. Users can
 * use this class to create instances of NP objects with their
 * desired parameters.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 *
 * @see NP
 */

public interface NPFactory {
    /**
     * The static instance which helps users to access to the methods in
     * this class.
     */
    public static NPFactory factory = null;

    /**
     * A factory method which creates a default instance of NP.
     * @return a default instance of NP
     */
    public NP create();

    /**
     * A factory method which creates an instance of NP with the
     * given lexical entry.
     * @param lex the lexical entry of the np.
     * @return an instance of NP with the given lexical entry
     */
    public NP create(String lex) 
	throws InvalidConstructorException;

    /**
     * A factory method which creates an instance of NP with the
     * given head.
     * @param head the head entry of the np.
     * @return an instance of NP with the given head entry
     */
    public NP create(FD head) throws InvalidConstructorException;
}
