/*
 * @(#)ParticFactory.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge;

/**
 * This class holds the factory methods for the Partic class. Users
 * can use this class to create instances of Partic objects with their
 * desired parameters.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 *
 * @see Partic
 */

public interface ParticFactory {
    /**
     * The static instance which helps users to access to the methods in
     * this class.
     */
    public static ParticFactory factory = null;

    /**
     * A factory method which creates a default instance of Partic.
     * @return a default instance of Partic
     */
    public Partic create();

    /**
     * A factory method which creates an instance of Partic with the
     * given name and the body of the participant. If invalid name and
     * body are entered, an exception will be thrown.
     * @param particName the name of the type of participant
     * @param particbody the specification of the participant
     * @exception InvalidConstructorException
     * @return an instance of Partic with the given participant's
     * name and body
     */
    public Partic create(String particName, FD particBody) 
	throws InvalidConstructorException;

    /**
     * A factory method which creates an instance of Partic with the
     * given names and the bodies of the participant. There are a lot
     * of instances participants come in the form of pairs. This
     * factory method allows users to create participant pairs in one
     * line of code. If invalid names and body entries are entered, an
     * exception will be thrown.
     * @param subjectName the name of the type of the first participant
     * @param subjectBody the body specification of the first participant
     * @param objectName the name of the type of the other participant
     * @param objectBody the body specification of the other participant
     * @exception InvalidConstructorException
     * @return an instance of Partic with the given participant pair.
     */
    public Partic create(String subjectName, FD subjectBody, 
			 String objectName, FD objectBody)
	throws InvalidConstructorException;
}
