/*
 * @(#)PersonalPronoun.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge;

/**
 * The personal-pronoun category. In general, a personal-pronoun is
 * used as participants of processes. For a personal-pronoun, at the
 * very least, user has to specify whether it is first, second or
 * third person and also whether it is plural. User can also set the
 * gender of the pronoun. The person and the gender of the pronoun can
 * be set using the static constants provided in this class. For
 * example, if user wants to set it to be first person, he/she can use
 * setPerson(PersonalPronoun.FIRST) to achieve the task. There are
 * methods to set the person, the plurality and the gender of the
 * personal-pronoun. A factory method is also provided to serve the
 * functionality of a constructor which user feeds in all the
 * properties of the desired pronoun as parameters to the method.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 *
 * @see PersonalPronounFactory
 */

public interface PersonalPronoun extends FD {
  /**
   * A method to set the person of the personal-pronoun.
   * @param person set whether the personal-pronoun to be first,
   * second or third person. User can use the static constants in this
   * class as parameters.
   */
  public void setPerson(String person);

  /**
   * A method to set whether the personal-pronoun is plural. User can
   * use the constants in the FDProperties to set the pluraity.
   * @param pluraity true to be plural and false to be singular
   * @see FDProperties
   */
  public void setPlural(boolean plurality);

  /**
   * A method to set the gender of the personal-pronoun.
   * @param gender can use the static variables in this class as
   * paratmers
   */
  public void setGender(String gender);

  /**
   * Set the personal-pronoun to be masculine.
   */
  public static final String MASCULINE = "masculine";

  /**
   * Set the personal-pronoun to be feminine.
   */
  public static final String FEMININE = "feminine";

  /**
   * Set the personal-pronoun to be gender neutral.
   */
  public static final String NEUTRAL = "neuter";

  /**
   * The variable to set the pronoun to first person.
   */
  public static final String FIRST = "first";

  /**
   * The variable to set the pronoun to second person.
   */
  public static final String SECOND = "second";

  /**
   * The variable to set the pronoun to third person.
   */
  public static final String THIRD = "third";
}
