/*
 * @(#)PersonalPronounFactory.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge;

/**
 * This class holds the factory methods for the PersonalPronoun
 * class. Users can use this class to create instances of
 * PersonalPronoun objects with their desired parameters.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 *
 * @see PersonalPronoun
 */

public interface PersonalPronounFactory {
    /**
     * The static instance which helps users to access to the methods in
     * this class.
     */
    public static PersonalPronounFactory factory = null;

    /**
     * A factory method which creates a default instance of
     * PersonalPronoun.
     * @return a default instance of PersonalPronoun
     */
    public PersonalPronoun create();

    /**
     * A factory method which computes and returns an instance of
     * PersonalPronoun with the given specification of the whether
     * the FD is in first, second or third person.
     * @param person specify whether the personal-pronoun should be
     * first, second or third person.  Can use the static constants as
     * parameters, example: PersonalPronoun.SECOND
     * @return an instance of PersonalPronoun with the given
     * parameters
     */
    public PersonalPronoun create(String person) 
	throws InvalidConstructorException;

    /**
     * A factory method which computes and returns an instance of
     * PersonalPronoun.
     * @param person specify whether the personal-pronoun should be
     * first, second or third person.  Can use the static constants as
     * parameters, example: PersonalPronoun.SECOND
     * @param plurality specify whether the personal-pronoun should be
     * plural or singular.
     * @param gender specify the gender of the personal-pronoun, can
     * use the static constants in this class (example:
     * PersonalPronoun.NEUTRAL) to feed in as parameters
     * @return an instance of PersonalPronoun with the given
     * parameters
     */
    public PersonalPronoun create(String person, boolean plurality, String gender)
	throws InvalidConstructorException;
}
