/*
 * @(#)PredModFactory.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge;

/**
 * This class holds the factory methods for the PreMod class. Users can
 * use this class to create instances of PreMod objects with their
 * desired parameters.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 *
 * @see PreMod
 */

public interface PreModFactory {
    /**
     * The static instance which helps users to access to the methods in
     * this class.
     */
    public static PreModFactory factory = null;

    /**
     * A factory method which creates a default instance of PreMod.
     * @return a default instance of PreMod
     */
    public PreMod create();

    /**
     * A factory method which takes it the instrument of a
     * pred-modifier as parameter to compute and return an instance of
     * PreMod. Exception will be thrown when the instrument FD is
     * invalid.
     * @param instrument the instrument of the pred-modifier
     * @exception InvalidPathException
     * @exception InvalidConstructorException
     * @return an instance of PreMod with the given instrument
     */
    public PreMod create(FD instrument) 
	throws InvalidPathException, InvalidConstructorException;
}
