/*
 * @(#)Proc.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge;

/**
 * The process of a FD. This is used together with the Clause and the
 * Partic class in order to create a clause sentence. There are
 * methods in this class to set and to create various properties of a
 * process. Moreover, this interface also provides various constants
 * to help users setting the properties of a process. For example,
 * when user wants to set the process type of the Process to be
 * material, user can just use setProcessType(Proc.MATERIAL). Factory
 * methods are also provided to help users to construct instance of
 * Proc in a more efficient fashion.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 *
 * @see ProcFactory
 * @see Clause
 * @see Partic
 * @see #setProcessType(String processType)
 * @see #MATERIAL
 */

public interface Proc extends FD {
    /**
     * A method to set the type of the process
     * @param type the type of the process
     */
     public void setProcessType(String processType);

    /**
     * A method to set the effect-type of the process
     * @param effectType the effect-type of the process
     */
     public void setEffectType(String effectType);

    /**
     * A method to set the lexical of the process
     * @param lex the lexical word of the process
     */
     public void setLex(String lex);

    /**
     * A method to set the mode of the process
     * @param mode the mode of the process
     */
     public void setMode(String mode);

     /**
      * A method to set the polarity of the process
      * @param polarity the options are given as static variables in FDProperties interface.
      * @see FDProperties
      */
     public void setPolarity(String polarity);

     /**
      * A method to set whether the process is going to be effective
      * @param effective set whether the process is effective
      */
     public void setEffective(boolean effective);

     /**
      * A method to set whether the process is going to be agentive
      * @param agentive set whether the process is agentive
      */
     public void setAgentive(boolean agentive);

     /**
      * A method to set the relation-type of the process
      * @param relation_type
      */
     public void setRelationType(String relation_type);


    // The static variables
    /**
     * The composite type of a process
     */
     public static final String COMPOSITE =  "composite";

    /**
     * The material type of a process.
     */
     public static final String MATERIAL =  "material";

    /**
     * The mental type of a process.
     */
     public static final String MENTAL =  "mental";

    /**
     * The ascriptive type of a process.
     */
     public static final String ASCRIPTIVE =  "ascriptive";

    /**
     * The possessive type of a process.
     */
     public static final String POSSESSIVE =  "possessive";

    /**
     * The locative type of a process.
     */
     public static final String LOCATIVE =  "locative";

     /**
      * The agentive type of a process.
      */
      public static final String AGENTIVE =  "yes";

    /**
     * The non-agentive type of a process.
     */
      public static final String NON_AGENTIVE =  "no";

    /**
     * The simple effect-type of a process.
     */
      public static final String SIMPLE =  "simple";

    /**
     * The creative effect-type of a process.
     */
     public static final String CREATIVE =  "creative";

    /**
     * The dispositive effect-type of a process.
     */
     public static final String DISPOSITIVE =  "dispositive";

    /**
     * The with range effect-type (by process) of a process.
     */
      public static final String WITH_RANGE_PROC =  "process";

    /**
     * The with range effect-type (by participant) of a process.
     */
      public static final String WITH_RANGE_PARTIC =  "participant";

    /**
     * The attributive effect-type of a process.
     */
     public static final String ATTRIBUTIVE_EFFECT =  "attributive";

    /**
     * The variable to set the process to be effective.
     */
      public static final String EFFECTIVE =  "yes";

    /**
     * The variable to set the process to be non-effective.
     */
      public static final String NON_EFFECTIVE =  "no";

    /**
     * Set the mode of the process to be attributive. (Default)
     */
     public static final String ATTRIBUTIVE_MODE =  "attributive";

    /**
     * Set the mode of the process to be equative.
     */
     public static final String EQUATIVE =  "equative";

     /**
      * Set the process to be natural
      */
      public static final String NATURAL =  "natural-phenom";

      /**
      * Set the process to be existential
      */
      public static final String EXISTENTIAL =  "existential";

      /**
      * Set the type of the process to be accompaniment
      */
      public static final String ACCOMPANIMENT =  "accompaniment";

      /**
      * Set the type of the process to be temporal
      */
      public static final String TEMPORAL =  "temporal";

      /**
      * Set the type of the process to be spatial
      */
      public static final String SPATIAL =  "spatial";

      /**
       * Set the relation-type to be ascriptive
       */
      public static final String ASCRIPTIVE_RELATION =  "ascriptive";

       /**
        * Set the relation-type to be possessive
        */
      public static final String POSSESSIVE_RELATION =  "possessive";

        /**
         * Set the relation-type to be locative
         */
      public static final String LOCATIVE_RELATION =  "locative";
}
