/*
 * @(#)ProcFactory.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge;

import java.util.Map;

/**
 * This class holds the factory methods for the Proc class. Users can
 * use this class to create instances of Proc objects with their
 * desired parameters.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 *
 * @see Proc
 */

public interface ProcFactory {
  /**
   * The static instance which helps users to access to the methods in
   * this class.
   */
  public static ProcFactory factory = null;

  /**
   * A factory method which creates a default instance of Proc.
   * @return a default instance of Proc
   */
  public Proc create();

  /**
   * A factory method which takes in the lexical entry and the process
   * type as parameters to compute and return an instance of Proc. An
   * exception will be thrown if the parameters are invalid.
   *
   * @param type the process type
   * @param lex the lexical entry/verb of the process
   * @exception InvalidConstructorException
   * @return an instance of Proc
   */
  public Proc create(String type, String lex) 
      throws InvalidConstructorException;

  /**
   * A factory method to compute and return an instance of Proc that
   * gives user the option to create an instance of Proc with all the
   * most common and most frequently used properties. If user does not
   * want to specify certain properties, simply put in a null for that
   * entry. However, as the minimum requirement for constructing a
   * proc, user has to at least supply the type (process type) and the
   * lexical entry. Otherwise, an InvalidConstructorException will be
   * thrown.
   *
   * @param type the process type
   * @param lex the lexical entry/verb of the process
   * @param effect_type the effect type of the process
   * @param agentive set whether the process is agentive
   * @param effective set whether the process is effective
   * @param mode the mode of the process
   * @param relation_type the relation_type of the process
   * @exception InvalidConstructorException
   * @return an instance of Proc
   */
  public Proc create(String type, String lex, String effect_type, boolean
                      agentive, boolean effective, String mode, String
		     relation_type, String polarity) 
      throws InvalidConstructorException;
}
