/*
 * @(#)ProperFactory.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge;

/**
 * This class holds the factory methods for the Proper class. Users can
 * use this class to create instances of Proper objects with their desired
 * parameters.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 *
 * @see Proper
 */

public interface ProperFactory {
    /**
     * The static instance which helps users to access to the methods in
     * this class.
     */
    public static ProperFactory factory = null;
    
    /**
     * A factory method which creates a default instance of ProperFactory.
     * @return a default instance of ProperFactory
     */
    public Proper create();

    /**
     * A factory method to compute and return an object of type Proper
     * with the given lexical entry An InvalidConstructorException
     * will be thrown if the given lexical entry is invalid.
     * @param lex the proper noun
     * @return an object of type Proper with the given lexical entry
     */
    public Proper create(String lex) throws InvalidConstructorException;

    /**
     * A factory method to compute and return an object of type Proper
     * with the given lexical entry and specification of plurality. An
     * InvalidConstructorException will be thrown if the given lexical
     * entry is invalid.
     * @param lex the proper noun
     * @param plurality set whether the proper noun should be plural,
     * true to be plural.
     * @return an object of type Proper with the given lexical entry
     * and plurality
     */
    public Proper create(String lex, boolean plurality) 
	throws InvalidConstructorException;
}
