/*
 * @(#)APFactoryH.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge.hashImpl;
import edu.columbia.surge.*;

/**
 * This class holds the factory methods for the AP classes. Users can
 * use this class to create instances of AP objects with their desired
 * parameters. A static keyword is used to instantiate an instance of
 * APFactoryH so that the static variable in this class will have
 * access to the create methods. Users can also create instances of
 * APH directly using the constructors of the APH class. The primary
 * reason of the creation of this class is to allow the APH class,
 * which implements the AP interface to have constructors while being
 * able to implement all the methods in the interface.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 *
 * @see APH
 */

public class APFactoryH implements APFactory {
    /**
     * The static variable that is used to call the create() methods
     * to create instances of the FD.
     */
    public static APFactoryH factory;

    /**
     * A constructor which is primarily used to construct an
     * APFactoryH object in order to access the method of this class.
     */
    private APFactoryH() { }

    static {
	factory = new APFactoryH();
    }

    /**
     * The factory method to create a default instance of APH without
     * ay parameters.
     * @return a default instance of APH
     */
    public AP create() {
	return new APH();
    }

    /**
     * The factory method to create an instance of APH with the given
     * lexical entry.
     * @param lex the lexical entry of the FD
     * @return an instance of APH which is instantiated with a given
     * lexical entry.
     */
    public AP create(String lex) throws InvalidConstructorException {
	return new APH(lex);
    }

    /**
     * The factory method to create an instance of APH with the given
     * head entry represented as a FD.
     * @head the head of the AP
     * @return an instance of APH which is instantiated with a given
     * head entry.
     */
    public AP create(FD head) throws InvalidConstructorException {
	return new APH(head);
    }
}
