/*
 * @(#)APH.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge.hashImpl;
import edu.columbia.surge.*;

/**
 * This is the class that implements the AP interface and is
 * implemented in the form of a HashMap as it is inherrited from the
 * FDH class. This class consists of methods and constructors to set
 * the required components of a AP. User can either use the APFactoryH
 * class or directly use the constructor of this class to create
 * instances of APH.
 * @see APFactoryH
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 */

public class APH extends FDH implements AP {
    /**
     * The default constructor. It calls the inherrited constructor so
     * that it can be hashed into the hash map. By default, any APH
     * object must have a FD entry (cat ap) to symbolize that it is an
     * AP object.
     */
    public APH() {
	super();
	this.put("cat", "ap");
    }

    /**
     * The constructor which takes in a lexical entry as parameter. If
     * the lexical entry is entered incorrectly, an
     * InvalidConstructorException will be thrown.
     * @param lex the lexical entry represented as a string.
     * @exception InvalidConstructorException
     */
    public APH(String lex) throws InvalidConstructorException {
	super();
	this.put("cat", "ap");
	if(lex == null || lex.equals(""))
	    throw new InvalidConstructorException("No lex entry.");
	this.setLex(lex);
    }

    /**
     * The constructor which takes in a head entry as parameter.
     * @param head the head entry represented as a FD object
     * @exception InvalidConstructorException
     */
    public APH(FD head) throws InvalidConstructorException {
	super();
	this.put("cat", "ap");
	if(head == null)
	    throw new InvalidConstructorException("No head entry.");
	this.setHead(head);
    }

    /**
     * A method to set the lexical entry of the AP
     * @param lex the lexical entry of the AP
     */
    public void setLex(String lex) {
	this.put("lex", lex);
    }

    /**
     * A method to set the head of the AP. This is used when the head
     * cannot be represented by a single word. Otherwise, use setLex()
     * instead.
     * @param head a FD representation of the head
     */
    public void setHead(FD head) {
	this.put("head", head);
    }
}
