/*
 * @(#)CircumFactoryH.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge.hashImpl;
import edu.columbia.surge.*;

/**
 * This class holds the factory methods for the Circum class. Users
 * can use this class to create instances of Circum objects with their
 * desired parameters. A static keyword is used to instantiate an
 * instance of CircumFactoryH so that the static variable "factory" in
 * this class will have access to the create methods. Users can also
 * create instances of CircumH directly using the constructors of the
 * Circum class. The primary reason of the creation of this class is
 * to allow the Circum class, which implements the Circum interface to
 * have constructors while being able to implement all the methods in
 * the interface.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 *
 * @see CircumH
 */

public class CircumFactoryH implements CircumFactory {
    public static CircumFactoryH factory;

    /**
     * A private constructor so that instances of this class cannot be
     * instantiated except using the static variable- "factory".
     */
    private CircumFactoryH() { }

    /**
     * Invoke an instance of the ClauseFactoryH so that the factory
     * variable will have access to the methods of this class.
     */
    static {
	factory = new CircumFactoryH();
    }

    /**
     * The default factory method which creates an default instance of
     * CircumH object without any parameters.
     * @return a default instance of CircumH.
     */
    public Circum create() {
	return new CircumH();
    }

    /**
     * The factory method which creates an instance of CircumH object
     * with the given entries that tell and specify the
     * circumstance. If invalid parameters are input, an exception
     * will be thrown.
     * @param propertyName the name of the circumstance property
     * @param propertyBody the body of the circumstance property
     * @param lex the possible lexical entry of the circumstance
     * @return an instance of CircumH instantiated with the property
     * name and the specified properties.
     * @exception InvalidConstructorException
     */
    public Circum create(String propertyName, FD propertyBody, 
			 String lex) 
	throws InvalidConstructorException {
	return new CircumH(propertyName, propertyBody, lex);
    }

    /**
     * The factory method which creates an instance of CircumH object
     * with the given entries that tell and specify the
     * circumstance. This constructor accounts for all possible
     * cirsumtances that users can specify. Among all the possible
     * input circumstance characteristics, users should only enter one
     * characteristic and set the rest of them be null. Otherwise, if
     * more than one characteristics is inputted, an exception should
     * be thrown. If invalid parameters are input, an exception will
     * be thrown.
     * @param behalf the behalf characteristics of the circumstance
     * @param effect the effect characteristics of the circumstance
     * @param inLoc the in-location characteristics of the
     * circumstance
     * @param manner the manner characteristics of the circumstance
     * @param purpose the purpose characteristics of the circumstance
     * @param reason the reason characteristics of the circumstance
     * @param time the time characteristics of the circumstance
     * @param lex the possible lexical entry of the circumstance
     * @return an instance of CircumH instantiated with the property
     * name and the specified properties.
     * @exception InvalidConstructorException
     */
    public Circum create(FD behalf, FD effect, FD inLoc, FD manner, 
			 FD purpose, FD reason, FD time, String lex) 
	throws InvalidConstructorException {
	return new CircumH(behalf, effect, inLoc, manner, purpose, reason, 
			   time, lex);
    }
}
