/*
 * @(#)CommonFactoryH.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge.hashImpl;
import edu.columbia.surge.*;

/**
 * This class holds the factory methods for the Common class. Users
 * can use this class to create instances of Common objects with their
 * desired parameters. A static keyword is used to instantiate an
 * instance of CommonFactoryH so that the static variable "factory" in
 * this class will have access to the create methods. Users can also
 * create instances of CommonH directly using the constructors of the
 * Common class. The primary reason of the creation of this class is
 * to allow the Common class, which implements the Common interface to
 * have constructors while being able to implement all the methods in
 * the interface.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 *
 * @see CommonH
 */

public class CommonFactoryH implements CommonFactory {
    /**
     * The static instance which helps users to access to the methods in
     * this class.
     */
    public static CommonFactoryH factory;

    /**
     * A private constructor so that instances of this class cannot be
     * instantiated except using the static variable- "factory".
     */
    private CommonFactoryH() { }

    /**
     * Invoke an instance of the ClauseFactoryH so that the factory
     * variable will have access to the methods of this class.
     */
    static {
	factory = new CommonFactoryH();
    }

    /**
     * A factory method which creates an instance of CommonH without
     * any given parameters.
     */
    public Common create() {
	return new CommonH();
    }

    /**
     * A factory method which creates an instance of CommonH with the
     * given lexical entry. If the lexical entry is invalid, an
     * InvalidConstructorException should be thrown.
     * @param lex lexical entry
     */
    public Common create(String lex) 
	throws InvalidConstructorException {
	return new CommonH(lex);
    }

    /**
     * A factory method which creates an instance of CommonH with the
     * given lexical entry and a boolean to specify whether the lex
     * should be definite.  If the lexical entry is invalid, an
     * InvalidConstructorException should be thrown.
     * @param lex lexical entry
     * @param definite set whether the lex should be definite. Input
     * true to be definite.
     */
    public Common create(String lex, boolean definite) 
	throws InvalidConstructorException {
	return new CommonH(lex, definite);
    }
}
