/*
 * @(#)CommonH.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge.hashImpl;
import edu.columbia.surge.*;

/**
 * The Common category for a FD. Methods to set the lex and the head
 * of the common category are provided. There are a lot of variations
 * you can make to the noun such as setting it to be definite,
 * plural... Since there are too many options and they are not common,
 * methods are not provided to set those properties. And setLex() will
 * be the only required/automate method provided here.  This is the
 * class that implements the Common interface and is implemented in
 * the form of a HashMap as it is inherrited from the FDH class. This
 * class consists of methods and constructors to set the required
 * components of a CommonH. User can either use the CommonFactoryH
 * class or directly use the constructor of this class to create
 * instances of CommonH.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 *
 * @see CommonFactoryH
 */

public class CommonH extends FDH implements Common {
    /**
     * Constructor which creates an instance of CommonH without any
     * given parameters.
     */
    public CommonH() {
	super();
	this.put("cat", "common");
    }

    /**
     * Constructor which creates an instance of CommonH with the given
     * lexical entry. If the lexical entry is invalid, an
     * InvalidConstructorException should be thrown.
     * @param lex lexical entry
     */
    public CommonH(String lex) throws InvalidConstructorException {
	super();
	this.put("cat", "common");

	if(lex == null || lex.equals(""))
	    throw new InvalidConstructorException("Empty lexical entry.");
	this.setLex(lex);
    }

    /**
     * Constructor which creates an instance of CommonH with the given
     * lexical entry and a boolean to specify whether the lex should
     * be definite.  If the lexical entry is invalid, an
     * InvalidConstructorException should be thrown.
     * @param lex lexical entry
     * @param definite set whether the lex should be definite. Input
     * true to be definite.
     */
    public CommonH(String lex, boolean definite) 
	throws InvalidConstructorException {
	super();
	this.put("cat", "common");

	if(lex == null || lex.equals(""))
	    throw new InvalidConstructorException("Empty lexical entry.");
	this.setLex(lex);
	this.setDefinite(definite);
    }

    /**
     * A method to set the head of the common category
     * @param lex the lexical entry of the common phrase
     */
    public void setLex(String lex) {
	this.put("lex", lex);
    }

    /**
     * A method to set whether the common cat should be definite
     * @param true to be definite, false to be non-definite
     */
    public void setDefinite(boolean definite) {
	if(definite)
	    this.put("definite", FDProperties.DEFINITE);
	else
	    this.put("definite", FDProperties.NON_DEFINITE);
    }
}
