/*
 * @(#)FDNullFactoryH.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge.hashImpl;
import edu.columbia.surge.*;

/**
 * This class holds the factory methods for the FDNull class. Users
 * can use this class to create instances of FDNull objects with their
 * desired parameters. A static keyword is used to instantiate an
 * instance of FDNullFactoryH so that the static variable "factory" in
 * this class will have access to the create methods. Users can also
 * create instances of FDNullH directly using the constructors of the
 * FDNull class. The primary reason of the creation of this class is
 * to allow the FDNull class, which implements the FDNull interface to
 * have constructors while being able to implement all the methods in
 * the interface.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 *
 * @see FDNullH
 */

public class FDNullFactoryH implements FDNullFactory {
    /**
     * The static instance which helps users to access to the methods
     * in this class.
     */
    public static FDNullFactoryH factory;

    /**
     * A private constructor so that instances of this class cannot be
     * instantiated except using the static variable- "factory".
     */
    private FDNullFactoryH() { }

    /**
     * Invoke an instance of the FDNullFactoryH so that the factory
     * variable will have access to the methods in this class.
     */
    static {
	factory = new FDNullFactoryH();
    }

    /**
     * A factory method which creates a default instance of FDH.
     * @return a default instance of FDH
     */
    public FDNull create() {
	return new FDNullH();
    }
}
