/*
 * @(#)FDRefFactoryH.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge.hashImpl;
import edu.columbia.surge.*;

/**
 * This class holds the factory methods for the FDRef class. Users can
 * use this class to create instances of FDRef objects with their
 * desired parameters. A static keyword is used to instantiate an
 * instance of FDRefFactoryH so that the static variable "factory" in
 * this class will have access to the create methods. Users can also
 * create instances of FDRefH directly using the constructors of the
 * FDRef class. The primary reason of the creation of this class is to
 * allow the FDRef class, which implements the FDRef interface to have
 * constructors while being able to implement all the methods in the
 * interface.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 *
 * @see FDRefH
 */

public class FDRefFactoryH implements FDRefFactory {

    /**
     * The static instance which helps users to access to the methods
     * in this class.
     */
    public static FDRefFactoryH factory;

    /**
     * A private constructor so that instances of this class cannot be
     * instantiated except using the static variable- "factory".
     */
    private FDRefFactoryH() { }

    /**
     * Invoke an instance of the FDRefFactoryH so that the factory
     * variable will have access to the methods of this class.
     */
    static {
	factory = new FDRefFactoryH();
    }

    /**
     * A factory method which creates an instance of FDRefH with the
     * given object to be referrenced to as the hole.
     * @param ref the hole of the FD, it is either a FD or a FDNull
     * object.
     * @return a default instance of FDH
     */
    public FDRef create(Object ref) {
	return new FDRefH(ref);
    }
}
