/*
 * @(#)NPFactoryH.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge.hashImpl;
import edu.columbia.surge.*;

/**
 * This class holds the factory methods for the NP class. Users can
 * use this class to create instances of NP objects with their desired
 * parameters. A static keyword is used to instantiate an instance of
 * NPFactoryH so that the static variable "factory" in this class will
 * have access to the create methods. Users can also create instances
 * of NPH directly using the constructors of the NP class. The primary
 * reason of the creation of this class is to allow the NP class,
 * which implements the NP interface to have constructors while being
 * able to implement all the methods in the interface.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 *
 * @see NPH
 */

public class NPFactoryH implements NPFactory {
    /**
     * The static instance which helps users to access to the methods
     * in this class.
     */
    public static NPFactoryH factory;

    /**
     * A private constructor so that instances of this class cannot be
     * instantiated except using the static variable- "factory".
     */
    private NPFactoryH() { }

    /**
     * Invoke an instance of the NPFactoryH so that the factory
     * variable will have access to the methods of this class.
     */
    static {
	factory = new NPFactoryH();
    }

    /**
     * A factory method which creates a default instance of NPH.
     * @return a default instance of NPH
     */
    public NP create() {
	return new NPH();
    }

    /**
     * A factory method which creates an instance of NPH with the
     * given lexical entry.
     * @param lex the lexical entry of the np.
     * @return an instance of NPH with the given lexical entry
     */
    public NP create(String lex) throws InvalidConstructorException {
	return new NPH(lex);
    }

    /**
     * A factory method which creates an instance of NPH with the
     * given head.
     * @param head the head entry of the np.
     * @return an instance of NPH with the given head entry
     */
    public NP create(FD head) throws InvalidConstructorException {
	return new NPH(head);
    }
}
