/*
 * @(#)NPH.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge.hashImpl;
import edu.columbia.surge.*;

/**
 * The NP category for a FD. Methods are provided to set the head and
 * the lex of the noun phrase. Users should only set either the head
 * or the lexical entry for each noun phrase, it does not make sense
 * to set both of them at the same time.  This class implements the NP
 * interface and is implemented in the form of a HashMap as it is
 * inherrited from the FDH class. This class consists of methods and
 * constructors to set the required components of a NP. User can
 * either use the NPFactoryH class or directly use the constructor of
 * this class to create instances of NPH.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 *
 * @see NPFactoryH
 */

public class NPH extends FDH implements NP {
    /**
     * Constructor. It creates a default instance of NPH.
     */
    public NPH() {
	super();
	this.put("cat", "np");
    }

    /**
     * Constructor. It creates an instance of NPH with the given
     * lexical entry.
     * @param lex the lexical entry of the np.
     */
    public NPH(String lex) throws InvalidConstructorException {
	super();
	this.put("cat", "np");

	if( lex == null || lex.equals("") )
	    throw new 
		InvalidConstructorException("Empty lexical entry.");
	else
	    this.setLex(lex);
    }

    /**
     * Constructor. It creates an instance of NPH with the given head.
     * @param head the head entry of the np.
     */
    public NPH(FD head) throws InvalidConstructorException {
	super();
	this.put("cat", "np");

	if( head == null )
	    throw new 
		InvalidConstructorException("Empty head.");
	else
	    this.setHead(head);
    }

    /**
     * A method to set the lexical of the NP
     * @param lex
     */
    public void setLex(String lex) {
	this.put("lex", lex);
    }

    /**
     * A method to set the head of the NP
     * @param head a FD representation of the head
     */
    public void setHead(FD head) {
	this.put("head", head);
    }
}
