/*
 * @(#)PPH.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge.hashImpl;
import edu.columbia.surge.*;

/**
 * The PP (prepositional phrase) category for a FD. Methods are
 * provided to set the preposition and the np (noun phrase) which is
 * essential in creating PPs. Factory methods are also provided for
 * easier constructing purpose.  User can either use the PPFactoryH
 * class or directly use the constructor of this class to create
 * instances of PPH.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 *
 * @see PP
 * @see PPFactoryH
 */

public class PPH extends NPH implements PP {
    /**
     * Constructor which creates a default instance of PPH.
     * @return a default instance of PPH
     */
    public PPH() {
	super();
	this.put("cat", "pp");
    }

    /**
     * Constructor which returns a PPH object with the input
     * preposition and the body of the NP which resides in the
     * prepositional phrase.
     * @param prep the preposition of the PP
     * @param np the NP within the PP
     * @return a PP object which has the properties of the given
     * parameters
     */
    public PPH(String prep, FD np) 
	throws InvalidConstructorException, InvalidPathException {
	super();
	this.put("cat", "pp");
	if( prep == null || prep.equals("") || np == null )
	    throw new InvalidConstructorException();
	this.setPrep(prep);
	this.setNP(np);
    }

    /**
     * A method to set the preposition of a prepositional phrase
     * @param preposition the user-specified preposition entry
     */
    public void setPrep(String preposition) 
	throws InvalidPathException {
	try {
	    this.putPathOverride("prep lex", preposition);
	}
	catch(InvalidPathException e) {
	}
    }

    /**
     * A method to set the NP within a PP
     * @param NP the user-specified NP body
     */
    public void setNP(FD np) {
	this.put("np", np);
    }
}
