/*
 * @(#)ParticFactoryH.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge.hashImpl;
import edu.columbia.surge.*;

/**
 * This class holds the factory methods for the Partic class. Users
 * can use this class to create instances of Partic objects with their
 * desired parameters. A static keyword is used to instantiate an
 * instance of ParticFactoryH so that the static variable "factory" in
 * this class will have access to the create methods. Users can also
 * create instances of ParticH directly using the constructors of the
 * Partic class. The primary reason of the creation of this class is
 * to allow the Partic class, which implements the Partic interface to
 * have constructors while being able to implement all the methods in
 * the interface.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 *
 * @see ParticH
 */

public class ParticFactoryH implements ParticFactory {
    /**
     * The static instance which helps users to access to the methods
     * in this class.
     */
    public static ParticFactoryH factory;

    /**
     * A private constructor so that instances of this class cannot be
     * instantiated except using the static variable- "factory".
     */
    private ParticFactoryH() { }

    /**
     * Invoke an instance of the NPFactoryH so that the factory
     * variable will have access to the methods of this class.
     */
    static {
	factory = new ParticFactoryH();
    }

    /**
     * A factory method which creates a default instance of ParticH.
     * @return a default instance of ParticH
     */
    public Partic create() {
	return new ParticH();
    }

    /**
     * A factory method which creates an instance of ParticH with the
     * given name and the body of the participant. If invalid name and
     * body are entered, an exception will be thrown.
     * @param particName the name of the type of participant
     * @param particbody the specification of the participant
     * @exception InvalidConstructorException
     * @return an instance of ParticH with the given participant's
     * name and body
     */
    public Partic create(String particName, FD particBody) 
	throws InvalidConstructorException {
	return new ParticH(particName, particBody);
    }

    /**
     * A factory method which creates an instance of ParticH with the
     * given names and the bodies of the participant. There are a lot
     * of instances participants come in the form of pairs. This
     * factory method allows users to create participant pairs in one
     * line of code. If invalid names and body entries are entered, an
     * exception will be thrown.
     * @param subjectName the name of the type of the first
     * participant
     * @param subjectBody the body specification of the first
     * participant
     * @param objectName the name of the type of the other participant
     * @param objectBody the body specification of the other
     * participant
     * @exception InvalidConstructorException
     * @return an instance of ParticH with the given partcipant pair.
     */
    public Partic create(String subjectName, FD subjectBody, 
			 String objectName, FD objectBody) 
	throws InvalidConstructorException {
	return new ParticH(subjectName, subjectBody, objectName, objectBody);
    }
}
