/*
 * @(#)PersonalPronounFactoryH.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge.hashImpl;
import edu.columbia.surge.*;

/**
 * This class holds the factory methods for the PersonalPronoun
 * class. Users can use this class to create instances of
 * PersonalPronoun objects with their desired parameters. A static
 * keyword is used to instantiate an instance of
 * PersonalPronounFactoryH so that the static variable "factory" in
 * this class will have access to the create methods. Users can also
 * create instances of PersonalPronounH directly using the
 * constructors of the PersonalPronoun class. The primary reason of
 * the creation of this class is to allow the PersonalPronoun class,
 * which implements the PersonalPronoun interface to have constructors
 * while being able to implement all the methods in the interface.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 *
 * @see PersonalPronounH
 */

public class PersonalPronounFactoryH implements PersonalPronounFactory {
    /**
     * The static instance which helps users to access to the methods
     * in this class.
     */
    public static PersonalPronounFactoryH factory;

    /**
     * A private constructor so that instances of this class cannot be
     * instantiated except using the static variable- "factory".
     */
    private PersonalPronounFactoryH() { }

    /**
     * Invoke an instance of the PersonalPronounFactoryH so that the
     * factory variable will have access to the methods of this class.
     */
    static {
	factory = new PersonalPronounFactoryH();
    }

    /**
     * A factory method which creates a default instance of
     * PersonalPronounH.
     * @return a default instance of PersonalPronounH
     */
    public PersonalPronoun create() {
	return new PersonalPronounH();
    }

    /**
     * A factory method which computes and returns an instance of
     * PersonalPronounH with the given specification of the whether
     * the FD is in first, second or third person.
     * @param person specify whether the personal-pronoun should be
     * first, second or third person.  Can use the static constants as
     * parameters, example: PersonalPronoun.SECOND
     * @return an instance of PersonalPronounH with the given
     * parameters
     */
    public PersonalPronoun create(String person) 
	throws InvalidConstructorException {
	return new PersonalPronounH(person);
    }

    /**
     * A factory method which computes and returns an instance of
     * PersonalPronounH.
     * @param person specify whether the personal-pronoun should be
     * first, second or third person.  Can use the static constants as
     * parameters, example: PersonalPronoun.SECOND
     * @param plurality specify whether the personal-pronoun should be
     * plural or singular.
     * @param gender specify the gender of the personal-pronoun, can
     * use the static constants in this class (example:
     * PersonalPronoun.NEUTRAL) to feed in as parameters
     * @return an instance of PersonalPronounH with the given
     * parameters
     */
    public PersonalPronoun create(String person, boolean plurality, 
				  String gender)
	throws InvalidConstructorException {
	return new PersonalPronounH(person, plurality, gender);
    }
}
