/*
 * @(#)PreModFactoryH.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge.hashImpl;
import edu.columbia.surge.*;

/**
 * This class holds the factory methods for the PreMod class. Users
 * can use this class to create instances of PreMod objects with their
 * desired parameters. A static keyword is used to instantiate an
 * instance of PreModFactoryH so that the static variable "factory" in
 * this class will have access to the create methods. Users can also
 * create instances of PreModH directly using the constructors of the
 * PreMod class. The primary reason of the creation of this class is
 * to allow the PreMod class, which implements the PreMod interface to
 * have constructors while being able to implement all the methods in
 * the interface.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 *
 * @see PreModH
 */


public class PreModFactoryH implements PreModFactory {
    /**
     * The static instance which helps users to access to the methods in
     * this class.
     */
    public static PreModFactoryH factory;

    /**
     * A private constructor so that instances of this class cannot be
     * instantiated except using the static variable- "factory".
     */
    private PreModFactoryH() { }

    /**
     * Invoke an instance of the PreModH so that the factory variable
     * will have access to the methods of this class.
     */
    static {
	factory = new PreModFactoryH();
    }

    /**
     * A factory method which creates a default instance of PreModH.
     * @return a default instance of PreModH
     */
    public PreMod create() {
	return new PreModH();
    }

    /**
     * A factory method which takes it the instrument of a
     * pred-modifier as parameter to compute and return an instance of
     * PreModH. Exception will be thrown when the instrucment FD is
     * invalid.
     * @param instrument the instrument of the pred-modifier
     * @exception InvalidPathException
     * @exception InvalidConstructorException
     * @return an instance of PreModH with the given instrument
     */
    public PreMod create(FD instrument) 
	throws InvalidPathException, InvalidConstructorException {
	return new PreModH(instrument);
    }
}
