/*
 * @(#)PreModH.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge.hashImpl;
import edu.columbia.surge.*;

/**
 * The pred-modif category. This class is also often used together
 * within a clause together with the Clause, Proc, Partic and
 * possibly, the Circum class. This class serves to define the
 * predefined modifier to further describe the process of a
 * clause. User can either use the PreModFactoryH class or directly
 * use the constructor of this class to create instances of PreModH.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 *
 * @PreModFactoryH
 * @see Clause
 * @see Proc
 * @see Partic
 * @see Circum
 */

public class PreModH extends FDH implements PreMod {
    /**
     * Constructor which creates a default instance of PreModH.
     * @return a default instance of PreModH
     */
    public PreModH() {
	super();
    }

    /**
     * Constructor which takes it the instrument of a pred-modifier as
     * parameter to compute and return an instance of
     * PreModH. Exception will be thrown when the instrucment FD is
     * invalid.
     * @param instrument the instrument of the pred-modifier
     * @exception InvalidConstructorException
     * @return an instance of PreModH with the given instrument
     */
    public PreModH(FD instrument) throws InvalidConstructorException {
	super();
	if(instrument == null)
	    throw new InvalidConstructorException("Empty instrument.");

	this.setInstrument(instrument);
    }

    /**
     * A method to set the instrument of the pred-modif
     * @param instrument specified in the form of a FD
     */
    public void setInstrument(FD instrument) {
	this.put("pred-motif", instrument);
    }
}
