/*
 * @(#)ProcFactoryH.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge.hashImpl;
import edu.columbia.surge.*;

/**
 * This class holds the factory methods for the Proc class. Users can
 * use this class to create instances of Proc objects with their
 * desired parameters. A static keyword is used to instantiate an
 * instance of ProcFactoryH so that the static variable "factory" in
 * this class will have access to the create methods. Users can also
 * create instances of ProcH directly using the constructors of the
 * Proc class. The primary reason of the creation of this class is to
 * allow the Proc class, which implements the Proc interface to have
 * constructors while being able to implement all the methods in the
 * interface.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 *
 * @see ProcH
 */

public class ProcFactoryH implements ProcFactory {
    /**
     * The static instance which helps users to access to the methods
     * in this class.
     */
    public static ProcFactoryH factory;

    /**
     * A private constructor so that instances of this class cannot be
     * instantiated except using the static variable- "factory".
     */
    private ProcFactoryH() {}

    /**
     * Invoke an instance of the ProcFactoryH so that the factory
     * variable will have access to the methods of this class.
     */
    static {
	factory = new ProcFactoryH();
    }

    /**
     * A factory method which creates a default instance of
     * ProcFactoryH.
     * @return a default instance of ProcFactoryH
     */
    public Proc create() {
	return new ProcH();
    }

    /**
     * A factory method which takes in the lexical entry and the
     * process type as parameters to compute and return an instance of
     * ProcH. An exception will be thrown if the parameters are
     * invalid.
     * @param type the process type
     * @param lex the lexical entry/verb of the process
     * @exception InvalidConstructorException
     * @return an instance of Proc
     */
    public Proc create(String type, String lex) 
	throws InvalidConstructorException
    {
	return new ProcH(type, lex);
    }

    /**
     * A factory method to compute and return an instance of ProcH
     * that gives user the option to create an instance of ProcH with
     * all the most common and most frequently used properties. If
     * user does not want to specify certain properties, simply put in
     * a null for that entry. However, as the minimum requirement for
     * constructing a proc, user has to at least supply the type
     * (process type) and the lexical entry. Otherwise, an
     * InvalidConstructorException will be thrown.
     * @param type the process type
     * @param lex the lexical entry/verb of the process
     * @param effect_type the effect type of the process
     * @param agentive set whether the process is agentive
     * @param effective set whether the process is effective
     * @param mode the mode of the process
     * @param relation_type the relation_type of the process
     * @exception InvalidConstructorException
     * @return an instance of Proc
     */
    public Proc create(String type, String lex, String effect_type, 
		       boolean agentive, boolean effective, String mode, 
		       String relation_type, String polarity) 
	throws InvalidConstructorException {
	return new ProcH(type, lex, effect_type, agentive, effective, mode, relation_type, polarity);
    }
}
