/*
 * @(#)ProperFactoryH.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge.hashImpl;
import edu.columbia.surge.*;

/**
 * This class holds the factory methods for the Proper class. Users
 * can use this class to create instances of Proper objects with their
 * desired parameters. A static keyword is used to instantiate an
 * instance of ProperFactoryH so that the static variable "factory" in
 * this class will have access to the create methods. Users can also
 * create instances of ProperH directly using the constructors of the
 * Proper class. The primary reason of the creation of this class is
 * to allow the Proper class, which implements the Proper interface to
 * have constructors while being able to implement all the methods in
 * the interface.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 *
 * @see ProperH
 */

public class ProperFactoryH implements ProperFactory {
    /**
     * The static instance which helps users to access to the methods in
     * this class.
     */
    public static ProperFactoryH factory;

    /**
     * A private constructor so that instances of this class cannot be
     * instantiated except using the static variable- "factory".
     */
    private ProperFactoryH() {
    }

    /**
     * Invoke an instance of the ProcFactoryH so that the factory
     * variable will have access to the methods of this class.
     */
    static {
	factory = new ProperFactoryH();
    }

    /**
     * A factory method which creates a default instance of
     * ProperFactoryH.
     * @return a default instance of ProperFactoryH
     */
    public Proper create() {
	return new ProperH();
    }

    /**
     * A factory method to compute and return an object of type Proper
     * with the given lexical entry An InvalidConstructorException
     * will be thrown if the given lexical entry is invalid.
     * @param lex the proper noun
     * @return an object of type Proper with the given lexical entry
     */
    public Proper create(String lex) throws InvalidConstructorException {
	return new ProperH(lex);
    }

    /**
     * A factory method to compute and return an object of type Proper
     * with the given lexical entry and specification of plurality. An
     * InvalidConstructorException will be thrown if the given lexical
     * entry is invalid.
     * @param lex the proper noun
     * @param plurality set whether the proper noun should be plural, true to be plural.
     * @return an object of type Proper with the given lexical entry and plurality
     */
    public Proper create(String lex, boolean plurality) 
	throws InvalidConstructorException {
	return new ProperH(lex, plurality);
    }
}
