/*
 * @(#)ProperH.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge.hashImpl;
import edu.columbia.surge.*;

/**
 * The proper category. This is usually used when user wants to
 * specify a name of a person. The lexical entry in the proper
 * category is usually the name, which is the proper noun
 * itself. There are methods to set the proper noun and also the
 * plurality of the noun. A factory method is available to construct a
 * Proper object in a more convenient fashion.  User can either use
 * the ProperH class or directly use the constructor of this class to
 * create instances of ProperH.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 */

public class ProperH extends FDH implements Proper {
    /**
     * Constructor which creates a default instance of ProperFactoryH.
     * @return a default instance of ProperFactoryH
     */
    public ProperH() {
	super();
	this.put("cat", "proper");
    }

    /**
     * Constructor to compute and return an object of type Proper with
     * the given lexical entry An InvalidConstructorException will be
     * thrown if the given lexical entry is invalid.
     * @param lex the proper noun
     * @return an object of type Proper with the given lexical entry
     */
    public ProperH(String lex) throws InvalidConstructorException {
	super();
	this.put("cat", "proper");

	if(lex == null || lex.equals(""))
	    throw new InvalidConstructorException("Empty lexical entry.");

	this.setLex(lex);
    }

    /**
     * Construtor to compute and return an object of type Proper with
     * the given lexical entry and specification of plurality. An
     * InvalidConstructorException will be thrown if the given lexical
     * entry is invalid.
     * @param lex the proper noun
     * @param plurality set whether the proper noun should be plural,
     * true to be plural.
     * @return an object of type Proper with the given lexical entry
     * and plurality
     */
    public ProperH(String lex, boolean plurality) 
	throws InvalidConstructorException {
	super();
	this.put("cat", "proper");
	if(lex == null || lex.equals(""))
	    throw new InvalidConstructorException("Empty lexical entry.");

	this.setLex(lex);

	this.setPlurality(plurality);
    }

    /**
     * A method to set the lex/proper noun of the proper category.
     * @param lex the proper noun
     */
    public void setLex(String lex) {
	this.put("lex", lex);
    }

    /**
     * A method to set the plurality of the proper noun.
     * @param plurality set true to be plural and false to be singular
     */
    public void setPlurality(boolean plurality) {
	if(plurality)
	    this.put("number", FDProperties.PLURAL);
	else
	    this.put("number", FDProperties.SINGULAR);
    }
}
