/*
 * @(#)UnifierCache.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge.unifier;
import edu.columbia.surge.*;
import java.util.Map;
import java.util.WeakHashMap;
import java.util.HashMap;

/**
 * A unifier cache. It wraps around another unifier instance, caching its
 * results. By defaults it uses a java.util.WeakHashMap to provide the
 * caching, although it can be subclassed to employ other memory allocation
 * tactics.
 *
 * @author Pablo Ariel Duboue (pablo@cs.columbia.edu)
 * @version alpha 0.1
 */


public class UnifierCache implements Unifier {

    /**
     * The cache. The keys are the WeakHashFDs and the values are
     * strings (thre result from the unification.
     */    
    protected Map cache; 

    /**
     * The unifier being wrapped.
     */
    protected Unifier unifier;

    /**
     * Constructor. Must specify the unifier to wrap.
     */
    public UnifierCache(Unifier unifier) {
	cache = new WeakHashMap();
	this.unifier = unifier;
    }

    /**
     * The unify method. It calls the unify method of the underlining
     * unifier if the fd is not in the cache.
     */
    public String unify(FD fd) {
	WeakHashFDH weakHashFD = new WeakHashFDH(fd);
	if (cache.containsKey(weakHashFD)) {
	    //System.err.println("* Cache hit!");
	    return (String) cache.get(weakHashFD);
	} else {
	    String result = unifier.unify(fd);
	    cache.put(weakHashFD, result);
	    return result;
	}
    }
}
