/*
 * @(#)UnifierClient.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge.unifier;
import edu.columbia.surge.*;
import java.net.Socket;
import java.io.*;

/**
 * An unifier that connects to a lisp server via TCP/IP
 *
 * @author Pablo Duboue (pablo@cs.columbia.edu
 * @version alpha 0.1
 */

public class UnifierClient implements Unifier {
    /**
     * Name of the server to connect.
     */
    protected String server;
    
    /**
     * Port of the server;
     */
    protected int port;

    /**
     * Unification limit. Defaults to 10,000.
     */
    protected int limit = 10000;

    /**
     * Default constructor, sets server to "localhost" and port to
     * 4000.
     */
    public UnifierClient() {
	this.server = "localhost";
	this.port = 4000;
    }

    /**
     * Constructor specifying server and port.
     *
     * @param server String specifying to connect to.
     * @param port int specifying the port connect to.
     */
    public UnifierClient(String server, int port) {
	this.server = server;
	this.port = port;
    }

    /**
     * Set unification limit.
     */
    public void setLimit(int limit) {
	this.limit = limit;
    }

    /**
     * Unify method, connects to the remote server and proceed to
     * unify.
     */
    public String unify(FD fd)  {
	try {
	    String fdStr = fd.toString();

	    Socket socket = new Socket(server,port);
	    
	    OutputStream os = socket.getOutputStream();
	    InputStream is = socket.getInputStream();
	    
	    PrintWriter pw = new PrintWriter(os);
	    BufferedReader br = 
		new BufferedReader(new InputStreamReader(is));
	    
	    pw.println("(in-package :fug5)");
	    pw.println("(uni-string '"  + fdStr + " :limit " + limit +  ")");
	    pw.flush();
	    
	    String line = null;
	    String result = null;
	    do {
		line = br.readLine();
		//System.out.println(line);
		if (br != null) result = line;
	    } while (line != null && !line.startsWith("\""));

	    pw.close();

	    
	    return result.substring(1,result.length()-1);
	} catch (Exception e) {
	    System.err.println("Exception:");
	    e.printStackTrace();
	    return "exception";
	}
    }
}
