/*
 * @(#)UnifierH.java alpha0.1
 *
 * Copyright 2002 Columbia University, All Rights Reserved.
 *
 * This software is distributed under the LGPL.
 *
 */

package edu.columbia.surge.unifier;
import edu.columbia.surge.*;
import java.io.*;

/**
 * A unifier that runs lisp FUF/SURGE through command line.
 *
 * @author Howard Chu (hhc42@columbia.edu)
 * @version alpha 0.1
 */

public class UnifierH implements Unifier {
    public UnifierH() {
    }

    public UnifierH(String fufDirectory, String outFile, 
		    String preLoadFile) {
	this.fufDirectory = fufDirectory;
	this.outFile = outFile;
	this.preLoadFile = preLoadFile;
    }

    public String unify(FD fd) {
	String fdString = fd.toString();
	String result = "";
	System.out.println(fdString);

	try {
	    // create the file and write the fdString to the file
	    // using the FileWriter fos.
	    File file = new File(outFile);
	    FileWriter fos = new FileWriter(file);
	    fos.write("(setf *fd* '" + fdString + ")");
	    fos.close();

	    // execute the command to try unifiy the FD in SURGE
	    execute();
	} catch(IOException e) {
	    e.printStackTrace(System.out);
	}
	return result;
    }

    private void execute() {
	try {
	    String[] commandArray = new String[4];
	    commandArray[0] = this.fufDirectory;
	    commandArray[1] = "alisp.exe";
	    commandArray[2] = "-L";
	    commandArray[3] = preLoadFile;
	    String command = this.fufDirectory + "alisp -L exec.l "; 

	    Process currentProcess = Runtime.getRuntime().exec(commandArray);
	    int exitVal = currentProcess.waitFor();
	    System.out.println("Process exitValue: " + exitVal);

	} catch(IOException e) {
	    e.printStackTrace(System.out);
	}
	catch(InterruptedException e) {
	    e.printStackTrace();
	}
    }

    public void setFUFDir(String fufDir) {
	fufDirectory = fufDir;
    }

    public void setOutFile(String newOutFile) {
	outFile = newOutFile;
    }

    public void setPreLoadFile(String prlFile) {
	preLoadFile = prlFile;
    }

    private String fufDirectory;
    private String outFile;
    private String preLoadFile;
}
